@@ -540,6 +540,12 @@ compare2qualvars <- function(data, dep_vars, indep_var,
   if (!(is.factor(data |> pull(indep_var)))) {
     data <- data |> mutate(!!indep_var := factor(!!sym(indep_var)))
   }
+  if(data |> pull(indep_var) |> nlevels() !=2){
+    stop(paste("Independent variable",indep_var,
+               "has",data |> pull(indep_var) |> nlevels(),
+               "levels but must have exactly 2.",
+               "Look into function compare_n_numvars."))
+  }
   for(var_i in dep_vars){
     if (!(is.factor(data |> pull(var_i)))) {
       data <- data |> mutate(!!var_i := factor(!!sym(var_i)))
@@ -699,7 +705,7 @@ compare2qualvars <- function(data, dep_vars, indep_var,
 #' @param pretext for function [formatP]
 #' @param mark for function [formatP]
 #' @param singleline Put all group levels in  a single line?
-#' @param spacer Text element to indent levels, defaults to "&nbsp;".
+#' @param spacer Text element to indent levels, defaults to " ".
 #' @param linebreak place holder for newline.
 #' @param prettynum Apply prettyNum to results?
 #'
@@ -729,7 +735,7 @@ compare_n_qualvars <- function(data, dep_vars, indep_var,
                                pretext = FALSE, mark = FALSE,
                                singleline = FALSE,
                                # newline=TRUE,
-                               spacer = "&nbsp;",
+                               spacer = " ",
                                linebreak = "\n",
                                prettynum = FALSE) {
   indentor <- paste0(rep(spacer, 5), collapse = "")
